==> elephant-archives-domain-0.0.448-sources.jar: com/xforceplus/ultraman/app/elephantarchives/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.elephantarchives.metadata;

/**
 *
 * @author ultraman
 * @since 2021-08-10
 */

public class PageMeta {
    public interface StyleSetup {
        static String code() {
            return "styleSetup";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface StorageManagement {
        static String code() {
            return "storageManagement";
        }
        static String name() {
            return "库位管理";
        }
    }
    public interface WatermarkSetup {
        static String code() {
            return "watermarkSetup";
        }
        static String name() {
            return "水印设置";
        }
    }
    public interface VoucherReceive {
        static String code() {
            return "voucherReceive";
        }
        static String name() {
            return "档案接收";
        }
    }
    public interface VoucherArrangement {
        static String code() {
            return "voucherArrangement";
        }
        static String name() {
            return "档案整理";
        }
    }
    public interface VoucherSafekeeping {
        static String code() {
            return "voucherSafekeeping";
        }
        static String name() {
            return "档案保管";
        }
    }
    public interface FilingHandle {
        static String code() {
            return "filingHandle";
        }
        static String name() {
            return "立卷待办";
        }
    }
    public interface Location {
        static String code() {
            return "location";
        }
        static String name() {
            return "新库位";
        }
    }
    public interface BorrowApplyInfo {
        static String code() {
            return "borrowApplyInfo";
        }
        static String name() {
            return "借阅申请管理";
        }
    }
    public interface Volume {
        static String code() {
            return "volume";
        }
        static String name() {
            return "档案待授权列表";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface VolumeOperation {
        static String code() {
            return "volumeOperation";
        }
        static String name() {
            return "档案分册";
        }
    }
    public interface GrantVolume {
        static String code() {
            return "grantVolume";
        }
        static String name() {
            return "档案已授权列表页";
        }
    }
    public interface Voucher {
        static String code() {
            return "voucher";
        }
        static String name() {
            return "档案查询";
        }
    }
    public interface Enterwarehouse {
        static String code() {
            return "enterwarehouse";
        }
        static String name() {
            return "档案入库";
        }
    }
    public interface BorrowApplyUser {
        static String code() {
            return "borrowApplyUser";
        }
        static String name() {
            return "借阅申请人";
        }
    }
    public interface Grant {
        static String code() {
            return "grant";
        }
        static String name() {
            return "已授权详情页";
        }
    }
    public interface Style {
        static String code() {
            return "style";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface BorrowApplyExamine {
        static String code() {
            return "borrowApplyExamine";
        }
        static String name() {
            return "借阅申请审核";
        }
    }
    public interface BorrowApplyExamineManager {
        static String code() {
            return "borrowApplyExamineManager";
        }
        static String name() {
            return "借阅申请审核-管理员";
        }
    }
    public interface DirectoryManage {
        static String code() {
            return "directoryManage";
        }
        static String name() {
            return "目录管理";
        }
    }
    public interface ArchiveTypeManage {
        static String code() {
            return "archiveTypeManage";
        }
        static String name() {
            return "档案类型管理";
        }
    }
    public interface FilingWaitCheck {
        static String code() {
            return "filingWaitCheck";
        }
        static String name() {
            return "待审批";
        }
    }
    public interface FilingChecking {
        static String code() {
            return "filingChecking";
        }
        static String name() {
            return "审批中";
        }
    }
    public interface FilingChecked {
        static String code() {
            return "filingChecked";
        }
        static String name() {
            return "已归档";
        }
    }
    public interface UnVoucher {
        static String code() {
            return "unVoucher";
        }
        static String name() {
            return "非会计凭证查询";
        }
    }
    public interface UnVoucherCollect {
        static String code() {
            return "unVoucherCollect";
        }
        static String name() {
            return "非凭证类档案采集";
        }
    }
    public interface EVatInvoice {
        static String code() {
            return "eVatInvoice";
        }
        static String name() {
            return "电子票夹";
        }
    }
    public interface VolumeAppraisalApply {
        static String code() {
            return "volumeAppraisalApply";
        }
        static String name() {
            return "档案鉴定申请单列表";
        }
    }
    public interface VolumeAppraisalAdd {
        static String code() {
            return "volumeAppraisalAdd";
        }
        static String name() {
            return "待添加鉴定档案列表";
        }
    }
    public interface VolumeAppraisalRelation {
        static String code() {
            return "volumeAppraisalRelation";
        }
        static String name() {
            return "档案鉴定申请单和档案关系列表";
        }
    }
    public interface InventoryWorkflow {
        static String code() {
            return "inventoryWorkflow";
        }
        static String name() {
            return "盘点工作流";
        }
    }
    public interface InventoryResult {
        static String code() {
            return "inventoryResult";
        }
        static String name() {
            return "盘点差异表";
        }
    }
    public interface Outsourcers {
        static String code() {
            return "outsourcers";
        }
        static String name() {
            return "外包商";
        }
    }
    public interface TransferWorkflow {
        static String code() {
            return "transferWorkflow";
        }
        static String name() {
            return "转移工作流";
        }
    }
    public interface ArchivesSortingTicket {
        static String code() {
            return "archivesSortingTicket";
        }
        static String name() {
            return "发票类档案整理";
        }
    }
    public interface AccountDataManagement {
        static String code() {
            return "accountDataManagement";
        }
        static String name() {
            return "会计资料管理";
        }
    }
    public interface ArchivesSortingBill {
        static String code() {
            return "archivesSortingBill";
        }
        static String name() {
            return "单据类档案整理";
        }
    }
    public interface ElectronicReceive {
        static String code() {
            return "electronicReceive";
        }
        static String name() {
            return "电子档案接收";
        }
    }
    public interface PaperReceive {
        static String code() {
            return "paperReceive";
        }
        static String name() {
            return "纸质档案接收";
        }
    }
    public interface AccountDataTypeConfig {
        static String code() {
            return "accountDataTypeConfig";
        }
        static String name() {
            return "资料类型配置";
        }
    }
    public interface ElectronicFiling {
        static String code() {
            return "electronicFiling";
        }
        static String name() {
            return "电子档案待归档";
        }
    }
    public interface ElectronicFilingSuccess {
        static String code() {
            return "electronicFilingSuccess";
        }
        static String name() {
            return "电子档案已归档";
        }
    }
    public interface BorrowApplyForUser {
        static String code() {
            return "borrowApplyForUser";
        }
        static String name() {
            return "借阅申请-管理员";
        }
    }
    public interface VolumeDetail {
        static String code() {
            return "volumeDetail";
        }
        static String name() {
            return "分册详情";
        }
    }
    public interface TransferOperation {
        static String code() {
            return "transferOperation";
        }
        static String name() {
            return "转移操作页";
        }
    }
    public interface ArchivesSortingAttachment {
        static String code() {
            return "archivesSortingAttachment";
        }
        static String name() {
            return "附件类档案整理";
        }
    }
    public interface ElecManualVoucherSorting {
        static String code() {
            return "elecManualVoucherSorting";
        }
        static String name() {
            return "电子手工凭证整理";
        }
    }
    public interface MaterialGrantVolume {
        static String code() {
            return "materialGrantVolume";
        }
        static String name() {
            return "实物借出或归还登记弹窗";
        }
    }
}

==> elephant-archives-domain-0.0.546-sources.jar: com/xforceplus/ultraman/app/elephantarchives/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.elephantarchives.metadata;

/**
 *
 * @author ultraman
 * @since 2021-09-09
 */

public class PageMeta {
    public interface StyleSetup {
        static String code() {
            return "styleSetup";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface StorageManagement {
        static String code() {
            return "storageManagement";
        }
        static String name() {
            return "库位管理";
        }
    }
    public interface WatermarkSetup {
        static String code() {
            return "watermarkSetup";
        }
        static String name() {
            return "水印设置";
        }
    }
    public interface VoucherReceive {
        static String code() {
            return "voucherReceive";
        }
        static String name() {
            return "档案接收";
        }
    }
    public interface VoucherArrangement {
        static String code() {
            return "voucherArrangement";
        }
        static String name() {
            return "档案整理";
        }
    }
    public interface VoucherSafekeeping {
        static String code() {
            return "voucherSafekeeping";
        }
        static String name() {
            return "档案保管";
        }
    }
    public interface FilingHandle {
        static String code() {
            return "filingHandle";
        }
        static String name() {
            return "立卷待办";
        }
    }
    public interface Location {
        static String code() {
            return "location";
        }
        static String name() {
            return "新库位";
        }
    }
    public interface BorrowApplyInfo {
        static String code() {
            return "borrowApplyInfo";
        }
        static String name() {
            return "借阅申请管理";
        }
    }
    public interface Volume {
        static String code() {
            return "volume";
        }
        static String name() {
            return "档案待授权列表";
        }
    }
    public interface ConfigSettings {
        static String code() {
            return "configSettings";
        }
        static String name() {
            return "系统配置";
        }
    }
    public interface VolumeOperation {
        static String code() {
            return "volumeOperation";
        }
        static String name() {
            return "档案分册";
        }
    }
    public interface GrantVolume {
        static String code() {
            return "grantVolume";
        }
        static String name() {
            return "档案已授权列表页";
        }
    }
    public interface Voucher {
        static String code() {
            return "voucher";
        }
        static String name() {
            return "档案查询";
        }
    }
    public interface Enterwarehouse {
        static String code() {
            return "enterwarehouse";
        }
        static String name() {
            return "档案入库";
        }
    }
    public interface BorrowApplyUser {
        static String code() {
            return "borrowApplyUser";
        }
        static String name() {
            return "借阅申请人";
        }
    }
    public interface Grant {
        static String code() {
            return "grant";
        }
        static String name() {
            return "已授权详情页";
        }
    }
    public interface Style {
        static String code() {
            return "style";
        }
        static String name() {
            return "样式设置";
        }
    }
    public interface BorrowApplyExamine {
        static String code() {
            return "borrowApplyExamine";
        }
        static String name() {
            return "借阅申请审核";
        }
    }
    public interface BorrowApplyExamineManager {
        static String code() {
            return "borrowApplyExamineManager";
        }
        static String name() {
            return "借阅申请审核-管理员";
        }
    }
    public interface DirectoryManage {
        static String code() {
            return "directoryManage";
        }
        static String name() {
            return "目录管理";
        }
    }
    public interface ArchiveTypeManage {
        static String code() {
            return "archiveTypeManage";
        }
        static String name() {
            return "档案类型管理";
        }
    }
    public interface FilingWaitCheck {
        static String code() {
            return "filingWaitCheck";
        }
        static String name() {
            return "待审批";
        }
    }
    public interface FilingChecking {
        static String code() {
            return "filingChecking";
        }
        static String name() {
            return "审批中";
        }
    }
    public interface FilingChecked {
        static String code() {
            return "filingChecked";
        }
        static String name() {
            return "已归档";
        }
    }
    public interface UnVoucher {
        static String code() {
            return "unVoucher";
        }
        static String name() {
            return "非会计凭证查询";
        }
    }
    public interface UnVoucherCollect {
        static String code() {
            return "unVoucherCollect";
        }
        static String name() {
            return "非凭证类档案采集";
        }
    }
    public interface EVatInvoice {
        static String code() {
            return "eVatInvoice";
        }
        static String name() {
            return "电子票夹";
        }
    }
    public interface VolumeAppraisalApply {
        static String code() {
            return "volumeAppraisalApply";
        }
        static String name() {
            return "档案鉴定申请单列表";
        }
    }
    public interface VolumeAppraisalAdd {
        static String code() {
            return "volumeAppraisalAdd";
        }
        static String name() {
            return "待添加鉴定档案列表";
        }
    }
    public interface VolumeAppraisalRelation {
        static String code() {
            return "volumeAppraisalRelation";
        }
        static String name() {
            return "档案鉴定申请单和档案关系列表";
        }
    }
    public interface InventoryWorkflow {
        static String code() {
            return "inventoryWorkflow";
        }
        static String name() {
            return "盘点工作流";
        }
    }
    public interface InventoryResult {
        static String code() {
            return "inventoryResult";
        }
        static String name() {
            return "盘点差异表";
        }
    }
    public interface Outsourcers {
        static String code() {
            return "outsourcers";
        }
        static String name() {
            return "外包商";
        }
    }
    public interface TransferWorkflow {
        static String code() {
            return "transferWorkflow";
        }
        static String name() {
            return "转移工作流";
        }
    }
    public interface ArchivesSortingTicket {
        static String code() {
            return "archivesSortingTicket";
        }
        static String name() {
            return "发票类档案整理";
        }
    }
    public interface AccountDataManagement {
        static String code() {
            return "accountDataManagement";
        }
        static String name() {
            return "会计资料管理";
        }
    }
    public interface ArchivesSortingBill {
        static String code() {
            return "archivesSortingBill";
        }
        static String name() {
            return "单据类档案整理";
        }
    }
    public interface ElectronicReceive {
        static String code() {
            return "electronicReceive";
        }
        static String name() {
            return "电子档案接收";
        }
    }
    public interface PaperReceive {
        static String code() {
            return "paperReceive";
        }
        static String name() {
            return "纸质档案接收";
        }
    }
    public interface AccountDataTypeConfig {
        static String code() {
            return "accountDataTypeConfig";
        }
        static String name() {
            return "资料类型配置";
        }
    }
    public interface ElectronicFiling {
        static String code() {
            return "electronicFiling";
        }
        static String name() {
            return "电子档案待归档";
        }
    }
    public interface ElectronicFilingSuccess {
        static String code() {
            return "electronicFilingSuccess";
        }
        static String name() {
            return "电子档案已归档";
        }
    }
    public interface BorrowApplyForUser {
        static String code() {
            return "borrowApplyForUser";
        }
        static String name() {
            return "借阅申请-管理员";
        }
    }
    public interface VolumeDetail {
        static String code() {
            return "volumeDetail";
        }
        static String name() {
            return "分册详情";
        }
    }
    public interface TransferOperation {
        static String code() {
            return "transferOperation";
        }
        static String name() {
            return "转移操作页";
        }
    }
    public interface ArchivesSortingAttachment {
        static String code() {
            return "archivesSortingAttachment";
        }
        static String name() {
            return "附件类档案整理";
        }
    }
    public interface ElecManualVoucherSorting {
        static String code() {
            return "elecManualVoucherSorting";
        }
        static String name() {
            return "电子手工凭证整理";
        }
    }
    public interface MaterialGrantVolume {
        static String code() {
            return "materialGrantVolume";
        }
        static String name() {
            return "实物借出或归还登记弹窗";
        }
    }
    public interface Testshitu0813 {
        static String code() {
            return "testshitu0813";
        }
        static String name() {
            return "testshitu0813";
        }
    }
    public interface OutBoundLock {
        static String code() {
            return "outBoundLock";
        }
        static String name() {
            return "出库锁定";
        }
    }
}
